pub fn discard(tab_id: &str) -> Result<(), LxAppError>Expand description
Discard a tab’s WebView to free memory while keeping its sidebar entry.
pub fn discard(tab_id: &str) -> Result<(), LxAppError>Discard a tab’s WebView to free memory while keeping its sidebar entry.