pub fn present(tab_id: &str) -> Result<BrowserTabInfo, BrowserAutomationError>Expand description
Mark tab_id active and ask the host shell to bring it onscreen.
pub fn present(tab_id: &str) -> Result<BrowserTabInfo, BrowserAutomationError>Mark tab_id active and ask the host shell to bring it onscreen.